@@ -23,6 +23,11 @@ def pipein():
         return pd.DataFrame()
 
 
+@register
+def describe():
+    print(pipein().describe())
+
+
 @register
 def cat(fname=None):
     if fname is None:
@@ -105,7 +110,6 @@ pandas_computations = [
     "cummin",
     "cumprod",
     "cumsum",
-    "describe",
     "diff",
     "kurt",
     "kurtosis",
